
<p align="center">
	👉 <a target="_blank" href="https://www.python-office.com/">项目官网：https://www.python-office.com/</a> 👈
</p>
<p align="center">
	👉 <a target="_blank" href="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg">本开源项目的交流群</a> 👈
</p>



-------------------------------------------------------------------------------


## 📚简介


wftools是python自动化办公的小工具的代码合集。

-------------------------------------------------------------------------------

## 📦安装

### 🍊pip 自动下载&更新

```
pip install -i https://pypi.tuna.tsinghua.edu.cn/simple wftools -U
```


-------------------------------------------------------------------------------

## 📝功能

[📘官网：https://www.python-office.com/](https://www.python-office.com/)

| 序号 | 项目介绍       | 代码地址 |
| ---- | -------------- | -------- |
| 1    | [合同和财务系统](https://mp.weixin.qq.com/s/7Cx9f1Re9tbJVajtNVmsVA) | [源码](https://github.com/CoderWanFeng/awesome-python-framework/tree/project/1%E3%80%81%E5%90%88%E5%90%8C%E7%B3%BB%E7%BB%9F)     |
| 2    | [人脸门禁系统](https://mp.weixin.qq.com/s/98X3nl-elyi7MYsU_uCeqA) | [源码](https://github.com/CoderWanFeng/awesome-python-framework/tree/project/2%E3%80%81Python%2BDjango%E5%AE%9E%E7%8E%B0%E5%9F%BA%E4%BA%8E%E4%BA%BA%E8%84%B8%E8%AF%86%E5%88%AB%E7%9A%84%E9%97%A8%E7%A6%81%E7%AE%A1%E7%90%86%E7%B3%BB%E7%BB%9F%E3%80%90%E6%BA%90%E7%A0%81%E3%80%91)     |
| 3    | [商场管理系统](https://mp.weixin.qq.com/s/0FR4o2ddPe-9C2ijlnTuAg) | [源码](https://github.com/CoderWanFeng/awesome-python-framework/tree/project/3、用Python实现一个商场管理系统(附源码))     |
| 4    | [报表自动化 + 邮件自动发送](https://mp.weixin.qq.com/s/RfG502Hez7UttfHMndc4eA) | [源码](https://github.com/CoderWanFeng/awesome-python-framework/tree/project/4%E3%80%81Python%E8%87%AA%E5%8A%A8%E5%8C%96%E5%8A%9E%E5%85%AC%E5%B0%8F%E7%A8%8B%E5%BA%8F%EF%BC%9A%E5%AE%9E%E7%8E%B0%E6%8A%A5%E8%A1%A8%E8%87%AA%E5%8A%A8%E5%8C%96%E5%92%8C%E8%87%AA%E5%8A%A8%E5%8F%91%E9%80%81%E5%88%B0%E7%9B%AE%E7%9A%84%E9%82%AE%E7%AE%B1)     |
| 5    | 爬取招聘网站 | [源码](https://github.com/CoderWanFeng/awesome-python-framework/tree/project/5、Python招聘岗位信息聚合系统（拥有爬虫爬取、数据分析、可视化、互动等功能）)     |




## 🏗️添砖加瓦


### 📐PR的建议

python-office欢迎任何人来添砖加瓦，贡献代码，建议提交的pr（pull request）符合一些规范，规范如下：

参与项目建设的步骤：
- 例如：你需要给python-office添加一个add方法。
   1. 你的Github账户名为：demo
   2. 于是你在./contributors新建了文件夹./demo
   3. 新建了add.py文件，编辑你的代码
   4. 编辑完成，提交pr到master分支（gitee或者GitHub，都可以）。可以注明你对自己功能的取名建议
   5. 晚枫收到后，会对各位的代码进行测试后，合并后打包上传到python官方库

### 📐代码规范

1. 注释完备，尤其每个新增的方法应按照Google Python文档规范标明方法说明、参数说明、返回值说明等信息，必要时请添加单元测试，如果愿意，也可以加上你的大名。
2. python-office的文档，需要进行格式化。注意：只能格式化你自己的代码
3. 请直接pull request到`master`分支。`master`是主分支，表示已经发布pypi库的版本。**未来参与人数增多，会开辟新的分支，请留意本文档的更新。**
4. 我们如果关闭了你的issue或pr，请不要诧异，这是我们保持问题处理整洁的一种方式，你依旧可以继续讨论，当有讨论结果时我们会重新打开。


### 🧬贡献代码的步骤

1. 在Gitee或者Github上fork项目到自己的repo
2. 把fork过去的项目也就是你的项目clone到你的本地
3. 修改代码
4. commit后push到自己的库
5. 登录Gitee或Github在你首页可以看到一个 pull request 按钮，点击它，填写一些说明信息，然后提交到master分支即可。
6. 等待维护者合并


### 🐞提供bug反馈或建议

提交问题反馈时，请务必填写和python-office代码本身有关的问题，不进行有关python学习，甚至是个人练习的知识答疑和讨论。

- [Github issue](https://github.com/CoderWanFeng/wftools/issues)

-------------------------------------------------------------------------------


## 📌联系作者


![CoderWanFeng](https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office-qr.jpg)